##  API Documentation
For more details on the Metrics API and supported functionalities, have a look at the
[OpenAPI docs![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Fmetrics%2Fv2%2Fdocs%2F "https://eu.leanix.net/services/metrics/v2/docs/"). There, all endpoints are explained with examples and descriptions.
